@@ -49,6 +49,11 @@ IMainWindow::IMainWindow(QObject *parent)
             this, SLOT(onLogMessagesTimer()));
     m_logMessageTimer.setSingleShot (true);
     m_logMessageTimer.start (10);
+
+    m_mixpanelTimer.setSingleShot (true);
+    connect(&m_mixpanelTimer, SIGNAL(timeout()),
+            &m_mixPanel, SLOT(flushEvents()));
+    connect(&m_mixPanel, SIGNAL(eventAdded()), this, SLOT(onMixEventAdded()));
 }//IMainWindow::IMainWindow
 
 void
@@ -195,7 +200,7 @@ IMainWindow::loginCompleted()
     mEvent.distinct_id = m_user;
     mEvent.distinct_id = mEvent.distinct_id.toLower ();
     mEvent.properties["os"] = Lib::ref().getOsDetails();
-    mEvent.properties["version"] = "0.4.1848";
+    mEvent.properties["version"] = "0.4.1851";
 
     do {
         if (ATTS_SUCCESS == task->status) {
@@ -658,3 +663,10 @@ IMainWindow::onUserAboutBtnClicked()
     QUrl url(ABOUT_URL);
     QDesktopServices::openUrl (url);
 }//IMainWindow::onUserAboutBtnClicked
+
+void
+IMainWindow::onMixEventAdded()
+{
+    m_mixpanelTimer.stop ();
+    m_mixpanelTimer.start (15 * 1000);
+}//IMainWindow::onMixEventAdded
